Merged revisions 71960 via svnmerge from
svn+ssh://pythondev@svn.python.org/python/trunk

........
  r71960 | georg.brandl | 2009-04-26 11:56:44 +0200 (So, 26 Apr 2009) | 1 line

  Move pydoc_topics module to its own subdirectory, so that no generated code is in Lib/.
........
diff --git a/Lib/pydoc.py b/Lib/pydoc.py
index 41dd6dd..dd4fdfd 100755
--- a/Lib/pydoc.py
+++ b/Lib/pydoc.py
@@ -1530,11 +1530,11 @@
     # These dictionaries map a topic name to either an alias, or a tuple
     # (label, seealso-items).  The "label" is the label of the corresponding
     # section in the .rst file under Doc/ and an index into the dictionary
-    # in pydoc_topics.py.
+    # in pydoc_data/topics.py.
     #
     # CAUTION: if you change one of these dictionaries, be sure to adapt the
     #          list of needed labels in Doc/tools/sphinxext/pyspecific.py and
     #          regenerate the pydoc_topics.py file by running
     #              make pydoc-topics
     #          in Doc/ and copying the output file into the Lib/ directory.
 
@@ -1809,11 +1809,11 @@
 
     def showtopic(self, topic, more_xrefs=''):
         try:
-            import pydoc_topics
+            import pydoc_data.topics
         except ImportError:
             self.output.write('''
 Sorry, topic and keyword documentation is not available because the
-module "pydoc_topics" could not be found.
+module "pydoc_data.topics" could not be found.
 ''')
             return
         target = self.topics.get(topic, self.keywords.get(topic))
@@ -1825,7 +1825,7 @@
 
         label, xrefs = target
         try:
-            doc = pydoc_topics.topics[label]
+            doc = pydoc_data.topics.topics[label]
         except KeyError:
             self.output.write('no documentation found for %s\n' % repr(topic))
             return
@@ -1530,11 +1530,11 @@
     # CAUTION: if you change one of these dictionaries, be sure to adapt the
     #          list of needed labels in Doc/tools/sphinxext/pyspecific.py and
-    #          regenerate the pydoc_topics.py file by running
+    #          regenerate the pydoc_data/topics.py file by running
     #              make pydoc-topics
     #          in Doc/ and copying the output file into the Lib/ directory.